@@ -4,13 +4,9 @@
 '''
 subset_MODIS
 
-Programa para Fazer um subset teemporal de um pixel de imagens MODIS
-Dentro dos limites Lat e Long determinados.
+Makes a subset of a pixel time series from MODIS 
+Chlorophyll images.
 
-Baseado em subset_MODIS.py
-
-Author =  Arnaldo Russo
-e-mail =  arnaldorusso@gmail.com
 '''
 
 
@@ -32,6 +28,8 @@ def extract_series(LATLIMS, LONLIMS, indir):
 
     names = []
     multi_pix = []
+    Lat = None
+    Lon = None
     for i in range(len(filelist)):
         A = SD(filelist[i])
         a = A.attributes()
